@@ -398,8 +398,7 @@ bool AddFolderDbVisitor::visitorData()
         while (m_sqlQuery->next()) {
             results.newFolder->id = m_sqlQuery->value(DBFolder::folder_id).toInt();
             results.newFolder->category = m_sqlQuery->value(DBFolder::category_id).toInt();
-            //新添加的记事本都是进行加密的，需要解密
-            results.newFolder->name = QByteArray::fromBase64(m_sqlQuery->value(DBFolder::folder_name).toByteArray());
+            results.newFolder->name = m_sqlQuery->value(DBFolder::folder_name).toString();
             results.newFolder->defaultIcon = m_sqlQuery->value(DBFolder::default_icon).toInt();
             results.newFolder->iconPath = m_sqlQuery->value(DBFolder::icon_path).toString();
             results.newFolder->folder_state = m_sqlQuery->value(DBFolder::folder_state).toInt();
@@ -447,12 +446,12 @@ bool AddFolderDbVisitor::prepareSqls()
                           DBFolder::folderColumnsName[DBFolder::modify_time].toUtf8().data(),
                           DBFolder::folderColumnsName[DBFolder::delete_time].toUtf8().data(),
                           DBFolder::folderColumnsName[DBFolder::encrypt].toUtf8().data(),
-                          param.newFolder->name.toLocal8Bit().toBase64().data(),
+                          param.newFolder->name.toUtf8().data(),
                           param.newFolder->defaultIcon,
                           createTime.toString(VNOTE_TIME_FMT).toUtf8().data(),
                           createTime.toString(VNOTE_TIME_FMT).toUtf8().data(),
                           createTime.toString(VNOTE_TIME_FMT).toUtf8().data(),
-                          1); //新添加记事本都进行加密，加密标志为1
+                          0);
 
         QString queryNewRec;
         queryNewRec.sprintf(NEWREC_FMT, VNoteDbManager::FOLDER_TABLE_NAME, DBFolder::folderColumnsName[DBFolder::folder_id].toUtf8().data());
@@ -580,10 +579,9 @@ bool AddNoteDbVisitor::visitorData()
             note->folderId = m_sqlQuery->value(DBNote::folder_id).toInt();
             note->noteType = m_sqlQuery->value(DBNote::note_type).toInt();
             note->encryption = m_sqlQuery->value(DBNote::encrypt).toInt();
-            //新添加的笔记是加密的，需要解密
-            note->noteTitle = QByteArray::fromBase64(m_sqlQuery->value(DBNote::note_title).toByteArray());
+            note->noteTitle = m_sqlQuery->value(DBNote::note_title).toString();
             //Parse meta data
-            QVariant metaData = QByteArray::fromBase64(m_sqlQuery->value(DBNote::meta_data).toByteArray());
+            QVariant metaData = m_sqlQuery->value(DBNote::meta_data);
 
             note->setMetadata(metaData);
             metaParser.parse(metaData, note);
@@ -648,12 +646,12 @@ bool AddNoteDbVisitor::prepareSqls()
                           DBNote::noteColumnsName[DBNote::encrypt].toUtf8().data(),
                           note->folderId,
                           note->noteType,
-                          noteTitle.toLocal8Bit().toBase64().data(),
-                          metaDataStr.toLocal8Bit().toBase64().data(),
+                          noteTitle.toUtf8().data(),
+                          metaDataStr.toUtf8().data(),
                           createTime.toString(VNOTE_TIME_FMT).toUtf8().data(),
                           createTime.toString(VNOTE_TIME_FMT).toUtf8().data(),
                           createTime.toString(VNOTE_TIME_FMT).toUtf8().data(),
-                          1); //新添加笔记都是加密的，加密标志为1
+                          0);
 
         QString updateSql;
 
@@ -889,57 +887,3 @@ bool DelNoteDbVisitor::prepareSqls()
 
     return fPrepareOK;
 }
-
-EncryptFolderDbVisitor::EncryptFolderDbVisitor(QSqlDatabase &db, const void *inParam, void *result)
-    : DbVisitor(db, inParam, result)
-{
-}
-
-bool EncryptFolderDbVisitor::prepareSqls()
-{
-    const VNoteFolder *folder = param.newFolder;
-    if (nullptr != folder) {
-        static constexpr char const *ENCRYPT_FOLDER_FMT = "UPDATE %s SET %s='%s', %s=%d WHERE %s=%lld;";
-        QString encrySql;
-        encrySql.sprintf(ENCRYPT_FOLDER_FMT,
-                         VNoteDbManager::FOLDER_TABLE_NAME,
-                         DBFolder::folderColumnsName[DBFolder::folder_name].toUtf8().data(),
-                         folder->name.toLocal8Bit().toBase64().data(),
-                         DBFolder::folderColumnsName[DBFolder::encrypt].toUtf8().data(),
-                         1,
-                         DBFolder::folderColumnsName[DBFolder::folder_id].toUtf8().data(),
-                         folder->id);
-        m_dbvSqls.append(encrySql);
-        return true;
-    }
-    return false;
-}
-
-EncryptNoteDbVisitor::EncryptNoteDbVisitor(QSqlDatabase &db, const void *inParam, void *result)
-    : DbVisitor(db, inParam, result)
-{
-}
-
-bool EncryptNoteDbVisitor::prepareSqls()
-{
-    const VNoteItem *note = param.newNote;
-    if (nullptr != note) {
-        static constexpr char const *ENCRYPT_NOTE_FMT = "UPDATE %s SET %s='%s', %s='%s', %s=%d WHERE %s=%lld AND %s=%d;";
-        QString encrySql;
-        encrySql.sprintf(ENCRYPT_NOTE_FMT,
-                         VNoteDbManager::NOTES_TABLE_NAME,
-                         DBNote::noteColumnsName[DBNote::note_title].toUtf8().data(),
-                         note->noteTitle.toLocal8Bit().toBase64().data(),
-                         DBNote::noteColumnsName[DBNote::meta_data].toUtf8().data(),
-                         note->metaDataConstRef().toByteArray().toBase64().data(),
-                         DBNote::noteColumnsName[DBNote::encrypt].toUtf8().data(),
-                         1,
-                         DBNote::noteColumnsName[DBNote::folder_id].toUtf8().data(),
-                         note->folderId,
-                         DBNote::noteColumnsName[DBNote::note_id].toUtf8().data(),
-                         note->noteId);
-        m_dbvSqls.append(encrySql);
-        return true;
-    }
-    return false;
-}
