@@ -306,13 +306,6 @@ void VNoteMainWindow::initShortcuts()
     m_stRecording->setAutoRepeat(false);
     connect(m_stRecording.get(), &QShortcut::activated, this, &VNoteMainWindow::onRecordShorcut);
 
-    //Save as Mp3
-    m_stSaveAsMp3.reset(new QShortcut(this));
-    m_stSaveAsMp3->setKey(Qt::CTRL + Qt::Key_P);
-    m_stSaveAsMp3->setContext(Qt::ApplicationShortcut);
-    m_stSaveAsMp3->setAutoRepeat(false);
-    connect(m_stSaveAsMp3.get(), &QShortcut::activated, this, &VNoteMainWindow::onSaveMp3Shortcut);
-
     //Save as Text
     m_stSaveAsText.reset(new QShortcut(this));
     m_stSaveAsText->setKey(Qt::CTRL + Qt::Key_S);
@@ -385,14 +378,8 @@ void VNoteMainWindow::initTitleBar()
     QWidget::setTabOrder(m_viewChange, m_imgInsert); //设置焦点传递顺序
 
     //捕捉标题栏最右边控件事件
-    QObject *btn = nullptr;
-    if (Utils::isWayland()) {
-        //wayland 显示时控件为菜单按钮
-        btn = titlebar()->findChild<QObject *>("DTitlebarDWindowOptionButton");
-    } else {
-        //x11显示时控件为关闭按钮
-        btn = titlebar()->findChild<QObject *>("DTitlebarDWindowCloseButton");
-    }
+    QObject *btn = titlebar()->findChild<QObject *>("DTitlebarDWindowCloseButton");
+
     if (nullptr != btn) {
         btn->installEventFilter(this);
     }
@@ -2264,13 +2251,6 @@ void VNoteMainWindow::onRecordShorcut()
     }
 }
 
-void VNoteMainWindow::onSaveMp3Shortcut()
-{
-    //    if (canDoShortcutAction()) {
-    //        m_rightView->saveMp3();
-    //    }
-}
-
 void VNoteMainWindow::onSaveNoteShortcut()
 {
     //多选笔记导出文本
